@@ -17,7 +17,7 @@ let ColorField = (function(window) {
   }
 
   function makeBgImage(color) {
-    return "linear-gradient(to left, " + color + " 5ch, white 5ch)";
+    return "linear-gradient(to left, " + color + " 5ch, #ddd 5ch, white calc(5ch + 1px))";
   }
 
   function updateColor(field) {
